@@ -7,5 +7,5 @@ def test_suite():
 
 if __name__ == '__main__':
     import sys, os
-    sys.path.append(os.path.join(os.path.dirname(__file__), 'src'))
+    sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'src'))
     unittest.main(defaultTest='test_suite')
